@@ -273,6 +273,8 @@ def _parse_side_bar(credentials: _Credentials.Credentials, url: str) -> dict:
     html = credentials.get_html(url)
     soup = _bs4.BeautifulSoup(html, 'lxml')
 
+    base_url = _re.findall(r"^https?://sigarra\.up\.pt/\w+/\w+/", url)[0]
+
     timetables_links_table = soup.find("table", {"class": "horario-semanas ecra"})
 
     if timetables_links_table == None:
@@ -295,7 +297,7 @@ def _parse_side_bar(credentials: _Credentials.Credentials, url: str) -> dict:
 
     result = {}
     for tag in timetable_tags:
-        result[_parse_dates(tag.string, academic_year)] = credentials.base_url.replace("/en/", "/pt/") + tag["href"]
+        result[_parse_dates(tag.string, academic_year)] = base_url + tag["href"]
     return result
 
 def parse_timetable(credentials: _Credentials.Credentials, url: str, ignore_coherence : bool = False) -> list:
@@ -404,6 +406,8 @@ def parse_timetable(credentials: _Credentials.Credentials, url: str, ignore_cohe
     except IndexError:
         weeks_url_query = ""
 
+    base_url = _re.findall(r"^https?://sigarra\.up\.pt/\w+/\w+/", url)[0]
+
     html = credentials.get_html(url)
     soup = _bs4.BeautifulSoup(html, 'lxml')
 
@@ -471,15 +475,13 @@ def parse_timetable(credentials: _Credentials.Credentials, url: str, ignore_cohe
                 "td", {"headers": "t3"}).string.split(":"))
             start = _datetime.time(hour=hour, minute=minute)
 
-            url = (credentials.base_url.replace("/en/", "/pt/") + row.find("td",
-                                          {"headers": "t6"}).a["href"]).lower()
+            url = (base_url + row.find("td", {"headers": "t6"}).a["href"]).lower()
 
             if "hor_geral.composto_desc" in url:
                 temp_html = credentials.get_html(url)
                 temp_soup = _bs4.BeautifulSoup(temp_html, 'lxml')
                 temp_content = temp_soup.find("div", {"id": "conteudoinner"})
-                url = (credentials.base_url.replace("/en/", "/pt/") + temp_content.find_all("a")
-                       [1]["href"]).lower()
+                url = (base_url + temp_content.find_all("a")[1]["href"]).lower()
             else:
                 url+=weeks_url_query # For some odd reason, single classes' urls don't include the start and finish weeks, a bug on sigarra's side perhaps?
 
